
from django.db import models
from django.utils.safestring import mark_safe
from django.utils.translation import gettext_lazy as _


class Country(models.Model):

    name = models.CharField(_("Country name"), max_length=255)

    flag_logo = models.ImageField(upload_to="countries")

    @property
    def flag_tag(self):
        if not self.flag_logo:
            return ''
        return mark_safe('<img src="%s" title="%s" />' % (
            self.flag_logo.url, self.name
        ))

    def __str__(self):
        return self.name

    class Meta:
        ordering = ('name', )
        verbose_name = _('Country')
        verbose_name_plural = _('Countries')



# Generated by Django 4.1.10 on 2023-08-23 16:45

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Country name')),
                ('flag_logo', models.ImageField(upload_to='countries')),
            ],
            options={
                'verbose_name': 'Country',
                'verbose_name_plural': 'Countries',
                'ordering': ('name',),
            },
        ),
    ]




from django.contrib import admin

from countries.models import Country


admin.site.register(
    Country,
    list_per_page=100,
    search_fields=['name'],
    list_display=['id', 'name', 'flag_tag']
)




from setuptools import setup, find_packages


version = '0.0.1'
url = 'https://github.com/pmaigutyak/mp-countries'


setup(
    name='django-mp-countries',
    version=version,
    description='Django countries app',
    author='Paul Maigutyak',
    author_email='pmaigutyak@gmail.com',
    url=url,
    download_url='{}/archive/{}.tar.gz'.format(url, version),
    packages=find_packages(),
    include_package_data=True,
    license='MIT',
)
